.. django-autocomplete-light documentation master file, created by
   sphinx-quickstart on Wed Feb  3 02:03:57 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-autocomplete-light's documentation!
=====================================================

.. include:: ../README.rst

Basics
------

.. toctree::
   :maxdepth: 2

   install
   tutorial

External app support
--------------------

.. toctree::
   :maxdepth: 2

   gfk
   gm2m
   genericm2m
   tagging
   taggit

API
---

.. toctree::
   :maxdepth: 1

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

